@@ -31,6 +31,7 @@ from . import imageio
 from . import rioserrors
 from . import rat
 from . import calcstats
+from . import fileinfo
 
 def setDefaultDriver():
     """
@@ -84,6 +85,8 @@ def setDefaultDriver():
     dfltDriverOptions = {}
     # Start with the old generic default options, applied to the default driver
     dfltDriverOptions[DEFAULTDRIVERNAME] = DEFAULTCREATIONOPTIONS
+    # Load some others which we wish to have as defaults, even if not set by the environment
+    dfltDriverOptions['GTiff'] = ['TILED=YES', 'COMPRESS=LZW', 'INTERLEAVE=BAND', 'BIGTIFF=IF_SAFER']
     # Now load any which are specified by environment variables, of the
     # form RIOS_DFLT_CREOPT_<drivername>
     driverOptVarPrefix = 'RIOS_DFLT_CREOPT_'
@@ -168,7 +171,7 @@ class ImageWriter(object):
         If you pass info, these other values will be determined from that
         
         """
-                    
+        self.filename = filename
         noninfoitems = [xsize,ysize,transform,projection,windowxsize,windowysize,overlap]
         if info is None:
             # check we have the other args
@@ -383,7 +386,7 @@ class ImageWriter(object):
     def close(self, calcStats=False, statsIgnore=None, progress=None, omitPyramids=False,
             overviewLevels=calcstats.DEFAULT_OVERVIEWLEVELS,
             overviewMinDim=calcstats.DEFAULT_MINOVERVIEWDIM, 
-            overviewAggType=None):
+            overviewAggType=None, autoColorTableType=rat.DEFAULT_AUTOCOLORTABLETYPE):
         """
         Closes the open dataset
         """
@@ -399,6 +402,50 @@ class ImageWriter(object):
         self.ds.FlushCache()
         del self.ds
         self.ds = None
+        
+        # Check whether we will need to add an auto color table
+        if autoColorTableType is not None:
+            # Does nothing if layers are not thematic
+            self.addAutoColorTable(autoColorTableType)
+    
+    def addAutoColorTable(self, autoColorTableType):
+        """
+        If autoColorTable has been set up for this output, then generate
+        a color table of the requested type, and add it to the current
+        file. This is called AFTER the Dataset has been closed, so is performed on
+        the filename. This only applies to thematic layers, so when we open the file
+        and find that the layers are athematic, we do nothing. 
+        
+        """
+        imgInfo = fileinfo.ImageInfo(self.filename)
+        if imgInfo.layerType == "thematic":
+            imgStats = fileinfo.ImageFileStats(self.filename)
+            ds = None
+            if calcstats.haveRFC40:
+                ds = gdal.Open(self.filename, gdal.GA_Update)
+
+            for i in range(imgInfo.rasterCount):
+                numEntries = imgStats[i].max + 1
+                clrTbl = rat.genColorTable(numEntries, autoColorTableType)
+                if not calcstats.haveRFC40:
+                    rat.setColorTable(self.filename, clrTbl, layernum=i+1)
+                else:
+                    # If we have the RFC40 facilities, then use them to write the colour table, 
+                    # because otherwise Sam will get cross with me. 
+                    band = ds.GetRasterBand(i+1)
+                    ratObj = band.GetDefaultRAT()
+                    redIdx, redNew = calcstats.findOrCreateColumn(ratObj, gdal.GFU_Red, "Red", gdal.GFT_Integer)
+                    greenIdx, greenNew = calcstats.findOrCreateColumn(ratObj, gdal.GFU_Green, "Green", gdal.GFT_Integer)
+                    blueIdx, blueNew = calcstats.findOrCreateColumn(ratObj, gdal.GFU_Blue, "Blue", gdal.GFT_Integer)
+                    alphaIdx, alphaNew = calcstats.findOrCreateColumn(ratObj, gdal.GFU_Alpha, "Alpha", gdal.GFT_Integer)
+                    # were any of these not already existing?
+                    if redNew or greenNew or blueNew or alphaNew:
+                        ratObj.WriteArray(clrTbl[:, 0], redIdx)
+                        ratObj.WriteArray(clrTbl[:, 1], greenIdx)
+                        ratObj.WriteArray(clrTbl[:, 2], blueIdx)
+                        ratObj.WriteArray(clrTbl[:, 3], alphaIdx)
+                    if not ratObj.ChangesAreWrittenToFile():
+                        band.SetDefaultRAT(ratObj)
 
     def doubleCheckCreationOptions(self, drivername, creationoptions):
         """
@@ -432,8 +479,8 @@ class ImageWriter(object):
             for optStr in creationoptions:
                 if optStr[:11] == 'BLOCKXSIZE=':
                     tiffBlockX = int(optStr[11:])
-                elif optStr[:11] == 'BLOCKXSIZE=':
-                    tiffBlockX = int(optStr[11:])
+                elif optStr[:11] == 'BLOCKYSIZE=':
+                    tiffBlockY = int(optStr[11:])
                 else:
                     newCreationoptions.append(optStr)
             
